aboutsummaryrefslogtreecommitdiff
path: root/common
diff options
context:
space:
mode:
Diffstat (limited to 'common')
-rw-r--r--common/events.h2
-rw-r--r--common/system.h2
-rw-r--r--common/unzip.cpp10
3 files changed, 7 insertions, 7 deletions
diff --git a/common/events.h b/common/events.h
index 11eb0c316e..371080c1b2 100644
--- a/common/events.h
+++ b/common/events.h
@@ -306,7 +306,7 @@ public:
/**
- * Initialise the event manager.
+ * Initialize the event manager.
* @note called after graphics system has been set up
*/
virtual void init() {}
diff --git a/common/system.h b/common/system.h
index e02779fe47..b584739b77 100644
--- a/common/system.h
+++ b/common/system.h
@@ -1031,7 +1031,7 @@ public:
};
-/** The global OSystem instance. Initialised in main(). */
+/** The global OSystem instance. Initialized in main(). */
extern OSystem *g_system;
#endif
diff --git a/common/unzip.cpp b/common/unzip.cpp
index f0590dcbfd..91f352f40a 100644
--- a/common/unzip.cpp
+++ b/common/unzip.cpp
@@ -349,7 +349,7 @@ typedef struct {
z_stream stream; /* zLib stream structure for inflate */
uLong pos_in_zipfile; /* position in byte on the zipfile, for fseek*/
- uLong stream_initialised; /* flag set if stream structure is initialised*/
+ uLong stream_initialized; /* flag set if stream structure is initialized*/
uLong offset_local_extrafield;/* offset of the local extra field */
uInt size_local_extrafield;/* size of the local extra field */
@@ -1073,7 +1073,7 @@ int unzOpenCurrentFile (unzFile file) {
return UNZ_INTERNALERROR;
}
- pfile_in_zip_read_info->stream_initialised=0;
+ pfile_in_zip_read_info->stream_initialized=0;
if ((s->cur_file_info.compression_method!=0) &&
(s->cur_file_info.compression_method!=Z_DEFLATED))
@@ -1096,7 +1096,7 @@ int unzOpenCurrentFile (unzFile file) {
err=inflateInit2(&pfile_in_zip_read_info->stream, -MAX_WBITS);
if (err == Z_OK)
- pfile_in_zip_read_info->stream_initialised = 1;
+ pfile_in_zip_read_info->stream_initialized = 1;
/* windowBits is passed < 0 to tell that there is no zlib header.
* Note that in this case inflate *requires* an extra "dummy" byte
* after the compressed stream in order to complete decompression and
@@ -1365,7 +1365,7 @@ int unzCloseCurrentFile(unzFile file) {
if (pfile_in_zip_read_info->crc32_data != pfile_in_zip_read_info->crc32_wait)
err=UNZ_CRCERROR;
}
- if (pfile_in_zip_read_info->stream_initialised)
+ if (pfile_in_zip_read_info->stream_initialized)
inflateEnd(&pfile_in_zip_read_info->stream);
#endif
@@ -1373,7 +1373,7 @@ int unzCloseCurrentFile(unzFile file) {
free(pfile_in_zip_read_info->read_buffer);
pfile_in_zip_read_info->read_buffer = NULL;
- pfile_in_zip_read_info->stream_initialised = 0;
+ pfile_in_zip_read_info->stream_initialized = 0;
free(pfile_in_zip_read_info);
s->pfile_in_zip_read=NULL;